@@ -1,9 +1,10 @@
 
 ''' Memory Image ConnScan worker. This worker utilizes the Rekall Memory Forensic Framework.
-    See Google Github: https://github.com/google/rekall
+    See Google Github: http://github.com/google/rekall
     All credit for good stuff goes to them, all credit for bad stuff goes to us. :)
 '''
 import os
+import hashlib
 import mem_base
 
 class MemoryImageConnScan(mem_base.MemoryImageBase):
@@ -15,6 +16,15 @@ class MemoryImageConnScan(mem_base.MemoryImageBase):
         super(MemoryImageConnScan, self).__init__()
         self.set_plugin_name('connscan')
 
+    def execute(self, input_data):
+        output = super(MemoryImageConnScan, self).execute(input_data)
+
+        # Organize the output a bit
+        output['tables'] = ['connscan']
+        output['connscan'] = output['sections']['Info']
+        del output['sections']
+        return output
+
 # Unit test: Create the class, the proper input and run the execute() method for a test
 import pytest
 @pytest.mark.rekall
@@ -23,26 +33,27 @@ def test():
 
     # This worker test requires a local server running
     import zerorpc
-    c = zerorpc.Client(timeout=120)
-    c.connect("tcp://127.0.0.1:4242")
+    workbench = zerorpc.Client(timeout=300, heartbeat=60)
+    workbench.connect("tcp://127.0.0.1:4242")
 
     # Store the sample
     data_path = os.path.join(os.path.dirname(os.path.realpath(__file__)), '../data/memory_images/exemplar4.vmem')
-    md5 = c.store_sample('exemplar4.vmem', open(data_path, 'rb').read(), 'mem')
-
-    # Unit test stuff
-    input_data = c.get_sample(md5)
+    with open(data_path, 'rb') as mem_file:
+        raw_bytes = mem_file.read()
+        md5 = hashlib.md5(raw_bytes).hexdigest()
+        if not workbench.has_sample(md5):
+            md5 = workbench.store_sample('exemplar4.vmem', open(data_path, 'rb').read(), 'mem')
 
     # Execute the worker (unit test)
     worker = MemoryImageConnScan()
-    output = worker.execute(input_data)
+    output = worker.execute({'sample':{'raw_bytes':raw_bytes}})
     print '\n<<< Unit Test >>>'
     import pprint
     pprint.pprint(output)
     assert 'Error' not in output
 
     # Execute the worker (server test)
-    output = c.work_request('mem_connscan', md5)
+    output = workbench.work_request('mem_connscan', md5)
     print '\n<<< Server Test >>>'
     import pprint
     pprint.pprint(output)
