@@ -17,15 +17,14 @@ def test():
     ''' view_log_meta.py: Unit test'''
     # This worker test requires a local server running
     import zerorpc
-    workbench = zerorpc.Client(timeout=120)
+    workbench = zerorpc.Client(timeout=300, heartbeat=60)
     workbench.connect("tcp://127.0.0.1:4242")
 
     # Generate input for the worker
     import os
     data_path = os.path.join(os.path.dirname(os.path.realpath(__file__)), '../data/log/system.log')
     md5 = workbench.store_sample('system.log', open(data_path, 'rb').read(), 'log')
-    input_data = workbench.get_sample(md5)
-    input_data.update(workbench.work_request('log_meta', md5))
+    input_data = workbench.work_request('log_meta', md5)
 
     # Execute the worker (unit test)
     worker = ViewLogMeta()
