@@ -30,7 +30,7 @@ class VTQuery(object):
     def execute(self, input_data):
         ''' Execute the VTQuery worker '''
         md5 = input_data['meta']['md5']
-        response = requests.get('https://www.virustotal.com/vtapi/v2/file/report', 
+        response = requests.get('http://www.virustotal.com/vtapi/v2/file/report', 
                                 params={'apikey':self.apikey,'resource':md5, 'allinfo':1})
 
         # Make sure we got a json blob back
@@ -69,15 +69,14 @@ def test():
 
     # This worker test requires a local server running
     import zerorpc
-    workbench = zerorpc.Client(timeout=120)
+    workbench = zerorpc.Client(timeout=300, heartbeat=60)
     workbench.connect("tcp://127.0.0.1:4242")
 
     # Generate input for the worker
     data_path = os.path.join(os.path.dirname(os.path.realpath(__file__)),
                              '../data/pdf/bad/067b3929f096768e864f6a04f04d4e54')
     md5 = workbench.store_sample('bad_pdf', open(data_path, 'rb').read(), 'pdf')
-    input_data = workbench.get_sample(md5)
-    input_data.update(workbench.work_request('meta', md5))
+    input_data = workbench.work_request('meta', md5)
 
     # Execute the worker (unit test)
     worker = VTQuery()
